mocks

package
v0.63.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 22, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Decider

type Decider struct {
	mock.Mock
}

Decider is an autogenerated mock type for the Decider type

func NewDecider

func NewDecider(t interface {
	mock.TestingT
	Cleanup(func())
}) *Decider

NewDecider creates a new instance of Decider. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*Decider) Decide

func (_m *Decider) Decide(ctx context.Context, additionalStrategies ...smpl.Strategy) (context.Context, bool, error)

Decide provides a mock function with given fields: ctx, additionalStrategies

func (*Decider) EXPECT

func (_m *Decider) EXPECT() *Decider_Expecter

type Decider_Decide_Call

type Decider_Decide_Call struct {
	*mock.Call
}

Decider_Decide_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Decide'

func (*Decider_Decide_Call) Return

func (_c *Decider_Decide_Call) Return(_a0 context.Context, _a1 bool, _a2 error) *Decider_Decide_Call

func (*Decider_Decide_Call) Run

func (_c *Decider_Decide_Call) Run(run func(ctx context.Context, additionalStrategies ...smpl.Strategy)) *Decider_Decide_Call

func (*Decider_Decide_Call) RunAndReturn

type Decider_Expecter

type Decider_Expecter struct {
	// contains filtered or unexported fields
}

func (*Decider_Expecter) Decide

func (_e *Decider_Expecter) Decide(ctx interface{}, additionalStrategies ...interface{}) *Decider_Decide_Call

Decide is a helper method to define mock.On call

  • ctx context.Context
  • additionalStrategies ...smpl.Strategy

Jump to